@@ -15,20 +15,20 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 // 
-using System;
 using Mono.Addins;
-
-using LongoMatch.Store;
-using LongoMatch.Interfaces.GUI;
+using LongoMatch.Core.Store;
+using LongoMatch.Core.Interfaces.GUI;
 
 namespace LongoMatch.Addins.ExtensionPoints
 {
 	[TypeExtensionPoint]
-	public interface IExportProject
+	public interface IExportProject: ILongoMatchPlugin
 	{
-		string GetMenuEntryName();
-		string GetMenuEntryShortName();
-		void ExportProject(Project project, IGUIToolkit guiToolkit);
+		string GetMenuEntryName ();
+
+		string GetMenuEntryShortName ();
+
+		void ExportProject (Project project, IGUIToolkit guiToolkit);
 	}
 }
 
