@@ -15,22 +15,23 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 // 
-using System;
 using Mono.Addins;
-
-using LongoMatch.Store;
-using LongoMatch.Interfaces.GUI;
+using LongoMatch.Core.Store;
 
 namespace LongoMatch.Addins.ExtensionPoints
 {
 	[TypeExtensionPoint]
-	public interface IImportProject
+	public interface IImportProject: ILongoMatchPlugin
 	{
-		string GetMenuEntryName();
-		string GetMenuEntryShortName();
-		string GetFilterName();
-		string GetFilter();
-		Project ImportProject(string filename);
+		string FilterName { get; }
+
+		string[] FilterExtensions { get; }
+
+		bool NeedsEdition { get; }
+
+		bool CanOverwrite { get; }
+
+		Project ImportProject (string filename);
 	}
 }
 
