@@ -18,25 +18,14 @@
 
 using System;
 
-namespace LongoMatch.Common
+namespace LongoMatch.Core.Common
 {
 
 	public struct CaptureSettings
 	{
-		public CaptureSourceType CaptureSourceType;
-		public string DeviceID;
-		public string SourceElement;
+		public Device Device;
+		public DeviceVideoFormat Format;
 		public EncodingSettings EncodingSettings;
-
-		public static CaptureSettings DefaultSettings() {
-			CaptureSettings settings = new CaptureSettings();
-			settings.CaptureSourceType = CaptureSourceType.System;
-			settings.EncodingSettings = new EncodingSettings(VideoStandards.P480_4_3,
-			                                                 EncodingProfiles.MP4,
-			                                                 EncodingQualities.Medium,
-			                                                 25, 1, "", true, false, 20);
-			return settings;
-		}
 	}
 	
 }
