@@ -18,9 +18,7 @@
 using System;
 using System.IO;
 
-using LongoMatch.Common;
-
-namespace LongoMatch.Common
+namespace LongoMatch.Core.Common
 {
 	public static class Cloner
 	{
@@ -30,9 +28,9 @@ namespace LongoMatch.Common
 			
 			Stream s = new MemoryStream();
 			using (s) {
-				SerializableObject.Save<T>(source, s);
+				Serializer.Save<T>(source, s, SerializationType.Binary);
 				s.Seek(0, SeekOrigin.Begin);
-				return SerializableObject.Load<T>(s);
+				return Serializer.Load<T>(s, SerializationType.Binary);
 			}
 		}
 	}
