@@ -21,13 +21,14 @@ using System.Collections.Generic;
 using Mono.Unix;
 
 
-namespace LongoMatch.Common
+namespace LongoMatch.Core.Common
 {
 
 
 	public class Device
 	{
 		public Device() {
+			Formats = new List<DeviceVideoFormat>();
 
 		}
 
@@ -52,6 +53,11 @@ namespace LongoMatch.Common
 			get;
 			set;
 		}
+
+		public List<DeviceVideoFormat> Formats {
+			get;
+			set;
+		}
 		
 		public string Desc  {
 			get {
@@ -59,4 +65,20 @@ namespace LongoMatch.Common
 			}
 		}
 	}
+	
+	public struct DeviceVideoFormat {
+		public int width;
+		public int height;
+		public int fps_n;
+		public int fps_d;
+		
+		public override string ToString ()
+		{
+			if (width == 0 && height == 0 && fps_n == 0 && fps_d == 0) {
+				return Catalog.GetString ("Default");
+			}
+			return string.Format ("{0}x{1}@{2}fps", width, height,
+			                      ((double)fps_n/fps_d).ToString ("#.##"));
+		}
+	}
 }
