@@ -16,8 +16,9 @@
 //  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 // 
 using System.Runtime.Serialization;
+using Newtonsoft.Json;
 
-namespace LongoMatch.Common
+namespace LongoMatch.Core.Common
 {
 	using System;
 	using System.IO;
@@ -29,6 +30,7 @@ namespace LongoMatch.Common
 #endif
 
 	[Serializable]
+	[JsonConverter (typeof(LongoMatchConverter))]
 	public class Image: ISerializable, IDisposable
 	{
 		SImage image;
@@ -48,10 +50,43 @@ namespace LongoMatch.Common
 			image.Dispose();
 		}
 		
-		public void Scale() {
-			Scale (Constants.THUMBNAIL_MAX_WIDTH, Constants.THUMBNAIL_MAX_HEIGHT);
+		public void ScaleInplace() {
+			ScaleInplace (Constants.MAX_THUMBNAIL_SIZE, Constants.MAX_THUMBNAIL_SIZE);
 		}
 		
+		public void ScaleFactor (int destWidth, int destHeight,
+		                         out double scaleX, out double scaleY, out Point offset) {
+			ScaleFactor (Width, Height, destWidth, destHeight, out scaleX, out scaleY, out offset);
+		}
+		
+		public static void ScaleFactor (int imgWidth, int imgHeight, int destWidth, int destHeight,
+		                                out double scaleX, out double scaleY, out Point offset)
+		{
+			int oWidth = 0;
+			int oHeight = 0;
+			
+			ComputeScale (imgWidth, imgHeight, destWidth, destHeight, out oWidth, out oHeight);
+			scaleX = (double) oWidth / imgWidth;
+			scaleY = (double) oHeight / imgHeight;
+			offset = new Point ((destWidth - oWidth) / 2, (destHeight - oHeight) / 2);
+		}
+		
+		public static void ComputeScale (int inWidth, int inHeight, int maxOutWidth, int maxOutHeight,
+		                                 out int outWidth, out int outHeight)
+		{
+			outWidth = maxOutWidth;
+			outHeight = maxOutHeight;
+
+			double par = (double)inWidth /(double)inHeight;
+			double outPar = (double)maxOutWidth /(double)maxOutHeight;
+				
+			if (outPar > par) {
+				outWidth = Math.Min (maxOutWidth, (int)(outHeight * par));
+			} else {
+				outHeight = Math.Min (maxOutHeight, (int)(outWidth / par));
+			}
+		} 
+		
 		// this constructor is automatically called during deserialization
 		public Image (SerializationInfo info, StreamingContext context) {
 			try {
@@ -72,7 +107,13 @@ namespace LongoMatch.Common
 		
 		
 #if HAVE_GTK
-		public byte[] Serialize () {
+		
+		public Image (string filename)
+		{
+			this.image = new SImage (filename);
+		}
+		
+		public virtual byte[] Serialize () {
 			if (image == null)
 				return null;
 			return image.SaveToBuffer("png");
@@ -82,12 +123,14 @@ namespace LongoMatch.Common
 			return new Image(new SImage(ser));
 		}
 		
-		public void Scale(int maxWidth, int maxHeight) {
+		public Image Scale(int maxWidth, int maxHeight) {
+			return new Image (Scale (image, maxWidth, maxHeight));
+		}
+		
+		public void ScaleInplace(int maxWidth, int maxHeight) {
 			SImage scalled;
-			int width, height;
 			
-			ComputeScale(image.Width, image.Height, maxWidth, maxHeight, out width, out height);
-			scalled= image.ScaleSimple(width, height, Gdk.InterpType.Bilinear);	
+			scalled = Scale (image, maxWidth, maxHeight);
 			image.Dispose();
 			image = scalled;
 		}
@@ -108,6 +151,21 @@ namespace LongoMatch.Common
 			}
 		}
 		
+		public static Image LoadFromResource (string resource)
+		{
+			return new Image (SImage.LoadFromResource (resource));
+		}
+		
+		public static Image LoadFromFile (string filename)
+		{
+			return new Image (new SImage (filename));
+		}
+		
+		public static Image LoadFromFile (string filename, int width, int height)
+		{
+			return new Image (new SImage (filename, width, height));
+		}
+		
 		public static Image Composite(Image image1, Image image2) {
 			SImage dest = new SImage(image1.Value.Colorspace, true, image1.Value.BitsPerSample,
 			                         image1.Width, image1.Height);
@@ -118,6 +176,13 @@ namespace LongoMatch.Common
 			return new Image(dest);
 		}
 		
+		SImage Scale (SImage pix, int maxWidth, int maxHeight) {
+			int width, height;
+			
+			ComputeScale(pix.Width, pix.Height, maxWidth, maxHeight, out width, out height);
+			return pix.ScaleSimple(width, height, Gdk.InterpType.Bilinear);	
+		}
+		
 #else
 		public byte[] Serialize () {
 			if (image == null)
@@ -158,20 +223,6 @@ namespace LongoMatch.Common
 		}
 #endif
 
-		private void ComputeScale (int inWidth, int inHeight, int maxOutWidth, int maxOutHeight, out int outWidth, out int outHeight)
-		{
-			outWidth = maxOutWidth;
-			outHeight = maxOutHeight;
-
-			if(inWidth > maxOutWidth || inHeight > maxOutHeight) {
-				double par = (double)inWidth /(double)inHeight;
-				
-				if(inHeight>inWidth)
-					outWidth = (int)(outHeight * par);
-				else
-					outHeight = (int)(outWidth / par);
-			}
-		} 
 	}
 }
 
