@@ -18,7 +18,14 @@
 using System;
 using System.IO;
 
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Interfaces;
+using LongoMatch.Core.Interfaces.GUI;
+using LongoMatch.Core.Interfaces.Multimedia;
+using LongoMatch.Core.Interfaces.Drawing;
+using LongoMatch.Core.Store;
+using System.Collections.Generic;
+using Newtonsoft.Json;
 
 namespace LongoMatch
 {
@@ -27,13 +34,62 @@ namespace LongoMatch
 		public static string homeDirectory;
 		public static string baseDirectory;
 		public static string configDirectory;
+		public static string dataDir;
+		
+		/* State */
+		public static IGUIToolkit GUIToolkit;
+		public static IMultimediaToolkit MultimediaToolkit;
+		public static IDrawingToolkit DrawingToolkit;
+		public static ITeamTemplatesProvider TeamTemplatesProvider;
+		public static ICategoriesTemplatesProvider CategoriesTemplatesProvider;
+		public static EventsBroker EventsBroker;
+		
+		public static IDataBaseManager DatabaseManager;
+		public static IRenderingJobsManager RenderingJobsManger;
+		
+		public static StyleConf Style;
+
 		static ConfigState state;
+
+		public static void Init () {
+			string home;
+
+			if (Environment.GetEnvironmentVariable ("LGM_UNINSTALLED") != null) {
+				Config.baseDirectory = Path.GetFullPath (".");
+				Config.dataDir = "../data";
+			} else {
+				Config.baseDirectory = Path.Combine (AppDomain.CurrentDomain.BaseDirectory, "../");
+				if (!Directory.Exists (Path.Combine (Config.baseDirectory, "share",
+				                                     Constants.SOFTWARE_NAME))) {
+					Config.baseDirectory = Path.Combine (Config.baseDirectory, "../");
+				}
+				if (!Directory.Exists (Path.Combine (Config.baseDirectory, "share",
+				                                     Constants.SOFTWARE_NAME)))
+					Log.Warning ("Prefix directory not found");
+				Config.dataDir = Path.Combine (Config.baseDirectory, "share",
+				                               Constants.SOFTWARE_NAME.ToLower ());
+			}
+			
+			/* Check for the magic file PORTABLE to check if it's a portable version
+			 * and the config goes in the same folder as the binaries */
+			if (File.Exists (Path.Combine (Config.baseDirectory, Constants.PORTABLE_FILE)))
+				home = Config.baseDirectory;
+			else
+				home = System.Environment.GetFolderPath (Environment.SpecialFolder.Personal);
+			
+			Config.homeDirectory = System.IO.Path.Combine (home, Constants.SOFTWARE_NAME);
+			if (Environment.OSVersion.Platform == PlatformID.Win32NT)
+				Config.configDirectory = Config.homeDirectory;
+			else
+				Config.configDirectory = System.IO.Path.Combine (home, "." +
+					Constants.SOFTWARE_NAME.ToLower ());
+		}
 		
 		public static void Load () {
 			if (File.Exists(Config.ConfigFile)) {
 				Log.Information ("Loading config from " + Config.ConfigFile);
 				try {
-					state = SerializableObject.Load<ConfigState>(Config.ConfigFile, SerializableObject.SerializationType.Xml);
+					state = Serializer.LoadSafe<ConfigState>(Config.ConfigFile);
 				} catch (Exception ex) {
 					Log.Error ("Error loading config");
 					Log.Exception (ex);
@@ -45,11 +101,15 @@ namespace LongoMatch
 				state = new ConfigState();
 				Save ();
 			}
+			Background = new Image (Path.Combine (Config.ImagesDir, Constants.BACKGROUND));
+			Copyright = Constants.COPYRIGHT;
+			License = Constants.LICENSE;
+			SoftwareName = Constants.SOFTWARE_NAME;
 		}
 		
 		public static void Save () {
 			try {
-				SerializableObject.Save(state, Config.ConfigFile, SerializableObject.SerializationType.Xml); 
+				Serializer.Save(state, Config.ConfigFile); 
 			} catch (Exception ex) {
 				Log.Error ("Errro saving config");
 				Log.Exception (ex);
@@ -58,7 +118,7 @@ namespace LongoMatch
 		
 		public static string ConfigFile {
 			get {
-				string filename = Constants.SOFTWARE_NAME.ToLower() + ".config";
+				string filename = Constants.SOFTWARE_NAME.ToLower() + "-1.0.config";
 				return Path.Combine(Config.ConfigDir, filename);
 			}
 		}
@@ -116,11 +176,23 @@ namespace LongoMatch
 
 		public static string ImagesDir {
 			get {
-				return RelativeToPrefix(String.Format("share/{0}/images",
-				                                      Constants.SOFTWARE_NAME.ToLower()));
+				return Path.Combine (dataDir, "images");
 			}
 		}
 		
+		public static string IconsDir {
+			get {
+				return Path.Combine (dataDir, "icons");
+			}
+		}
+		
+		public static string LibsDir {
+			get {
+				return RelativeToPrefix(Path.Combine ("lib",
+				                                      Constants.SOFTWARE_NAME.ToLower()));
+			}
+		}
+
 		public static string PluginsDir {
 			get {
 				return RelativeToPrefix(String.Format("lib/{0}/plugins",
@@ -130,13 +202,25 @@ namespace LongoMatch
 		
 		public static string PluginsConfigDir {
 			get {
-				return Path.Combine(configDirectory, "addins");
+				return Path.Combine(configDirectory, "addins-1.0");
 			}
 		}
 
 		public static string DBDir {
 			get {
-				return Path.Combine(configDirectory, "db");
+				return Path.Combine(homeDirectory, "db");
+			}
+		}
+
+		public static string AnalysisDir {
+			get {
+				return Path.Combine(DBDir, "analysis");
+			}
+			
+		}
+		public static string TeamsDir {
+			get {
+				return Path.Combine(DBDir, "teams");
 			}
 		}
 		
@@ -145,21 +229,53 @@ namespace LongoMatch
 		}
 		
 		#region Properties
+		
+		static public Image Background {
+			get;
+			set;
+		}
+
+		static public string Copyright {
+			get;
+			set;
+		}
+		
+		static public string License {
+			get;
+			set;
+		}
+		
+		static public string SoftwareName {
+			get;
+			set;
+		}
+
+		static public bool SupportsFullHD {
+			get;
+			set;
+		}
+
 		static public Image FieldBackground {
 			get {
-				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.FIELD_BACKGROUND));
+				return new Image (Path.Combine (Config.ImagesDir, Constants.FIELD_BACKGROUND));
 			}
 		}
 		
 		static public Image HalfFieldBackground {
 			get {
-				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.HALF_FIELD_BACKGROUND));
+				return new Image (Path.Combine (Config.ImagesDir, Constants.HALF_FIELD_BACKGROUND));
+			}
+		}
+		
+		static public Image HHalfFieldBackground {
+			get {
+				return new Image (Path.Combine (Config.ImagesDir, Constants.HHALF_FIELD_BACKGROUND));
 			}
 		}
 		
 		static public Image GoalBackground {
 			get {
-				return new Image (Gdk.Pixbuf.LoadFromResource (Constants.GOAL_BACKGROUND));
+				return new Image (Path.Combine (Config.ImagesDir, Constants.GOAL_BACKGROUND));
 			}
 		}
 		
@@ -351,11 +467,41 @@ namespace LongoMatch
 			}
 		}
 		
+		public static string DefaultTemplate {
+			get {
+				return state.defaultTemplate;
+			}
+			set {
+				state.defaultTemplate = value;
+				Save ();
+			}
+		}
+		
+		public static Hotkeys Hotkeys {
+			get {
+				return state.hotkeys;
+			}
+			set {
+				state.hotkeys = value;
+				Save ();
+			}
+		}
+		
+		public static ProjectSortMethod ProjectSortMethod {
+			get {
+				return state.projectSortMethod;
+			}
+			set {
+				state.projectSortMethod = value;
+				Save ();
+			}
+		}
 		#endregion
 
 	}
 	
 	[Serializable]
+	//[JsonConverter (typeof (LongoMatchConverter))]
 	public class ConfigState{
 		public bool fastTagging;
 		public bool autoSave;
@@ -375,6 +521,9 @@ namespace LongoMatch
 		public string autorenderDir;
 		public string lastRenderDir;
 		public bool reviewPlaysInSameWindow;
+		public string defaultTemplate;
+		public Hotkeys hotkeys;
+		public ProjectSortMethod projectSortMethod;
 		
 		public ConfigState () {
 			/* Set default values */
@@ -382,12 +531,12 @@ namespace LongoMatch
 			currentDatabase = Constants.DEFAULT_DB_NAME;
 			lang = null;
 			autoSave = false;
-			captureVideoStandard = VideoStandards.P480_16_9;
-			captureEncodingProfile = EncodingProfiles.MP4;
-			captureEncodingQuality = EncodingQualities.Medium;
-			renderVideoStandard = VideoStandards.P720_16_9;
-			renderEncodingProfile = EncodingProfiles.MP4;
-			renderEncodingQuality = EncodingQualities.High;
+			captureVideoStandard = VideoStandards.P480_16_9.Clone ();
+			captureEncodingProfile = EncodingProfiles.MP4.Clone ();
+			captureEncodingQuality = EncodingQualities.Medium.Clone ();
+			renderVideoStandard = VideoStandards.P720_16_9.Clone ();
+			renderEncodingProfile = EncodingProfiles.MP4.Clone ();
+			renderEncodingQuality = EncodingQualities.High.Clone ();
 			overlayTitle = true;
 			enableAudio = false;
 			fps_n = 25;
@@ -396,6 +545,9 @@ namespace LongoMatch
 			autorenderDir = null;
 			lastRenderDir = null;
 			reviewPlaysInSameWindow = true;
+			defaultTemplate = null;
+			hotkeys = new Hotkeys ();
+			projectSortMethod = ProjectSortMethod.Date;
 		}
 	}
 }
