@@ -18,27 +18,32 @@
 
 using System;
 
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Store;
 
-namespace LongoMatch.Handlers
+namespace LongoMatch.Core.Handlers
 {
 	public delegate void PlayListSegmentDoneHandler();
 	public delegate void SegmentClosedHandler();
 	public delegate void SegmentDoneHandler();
-	public delegate void SeekEventHandler(long pos);
+	public delegate void SeekEventHandler(Time pos, bool accurate);
+	public delegate void TogglePlayEventHandler(bool playing);
 	public delegate void VolumeChangedHandler(double level);
 	public delegate void NextButtonClickedHandler();
 	public delegate void PrevButtonClickedHandler();
 	public delegate void ProgressHandler(float progress);
 	public delegate void FramesProgressHandler(int actual, int total, Image frame);
-	public delegate void DrawFrameHandler(int time);
-	public delegate void EllpasedTimeHandler(int ellapsedTime);
+	public delegate void DrawFrameHandler (TimelineEvent play, int drawingIndex, MediaFileAngle angle, bool current);
+	public delegate void EllpasedTimeHandler(Time ellapsedTime);
 	public delegate void PlaybackRateChangedHandler (float rate);
-
-
-	public delegate void ErrorHandler(object o, string message);
-	public delegate void PercentCompletedHandler(object o, float percent);
-	public delegate void StateChangeHandler(object o, bool playing);
-	public delegate void TickHandler(object o, long currentTime, long streamLength,
-		float currentPosition, bool seekable);
+	
+	public delegate void DeviceChangeHandler(int deviceID);
+	public delegate void CaptureFinishedHandler (bool close);
+	public delegate void ErrorHandler(string message);
+	public delegate void PercentCompletedHandler(float percent);
+	public delegate void StateChangeHandler(bool playing);
+	public delegate void TickHandler(Time currentTime);
+	public delegate void MediaInfoHandler(int width, int height, int parN, int parD);
+	public delegate void EosHandler();
+	public delegate void ReadyToSeekHandler();
 }
