@@ -17,13 +17,14 @@
 // 
 using System;
 
-namespace LongoMatch.Interfaces.GUI
+namespace LongoMatch.Core.Interfaces.GUI
 {
 	public interface IBusyDialog
 	{
 		void Pulse();
 		void Destroy();
-		void Show();
+		void Show ();
+		void ShowSync ();
 	}
 }
 
