@@ -18,7 +18,7 @@
 using System;
 using System.Collections.Generic;
 
-namespace LongoMatch.Interfaces
+namespace LongoMatch.Core.Interfaces
 {
 	public interface IDataBaseManager
 	{
@@ -26,6 +26,7 @@ namespace LongoMatch.Interfaces
 		IDatabase Add (string name);
 		bool Delete (IDatabase db);
 		IDatabase ActiveDB { get; set; }
+		void UpdateDatabases ();
 		List<IDatabase> Databases { get; set; }
 	}
 }
