@@ -17,9 +17,9 @@
 // 
 using System;
 using System.Collections.Generic;
-using LongoMatch.Store;
+using LongoMatch.Core.Store;
 
-namespace LongoMatch.Interfaces
+namespace LongoMatch.Core.Interfaces
 {
 	public interface IDatabase
 	{
@@ -29,7 +29,7 @@ namespace LongoMatch.Interfaces
 		
 		void AddProject(Project project);
 		
-		void RemoveProject(Guid id);
+		bool RemoveProject(Guid id);
 		
 		void UpdateProject(Project project);
 		
@@ -39,6 +39,8 @@ namespace LongoMatch.Interfaces
 		
 		bool Delete ();
 		
+		void Reload ();
+		
 		string Name {get;}
 		
 		DateTime LastBackup {get;}
