@@ -17,9 +17,9 @@
 // 
 using System;
 using System.Collections.Generic;
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
 
-namespace LongoMatch.Interfaces
+namespace LongoMatch.Core.Interfaces
 {
 	public interface IRenderingJobsManager
 	{
@@ -32,6 +32,7 @@ namespace LongoMatch.Interfaces
 		void CancelAllJobs();
 		void AddJob(Job job);
 		List<Job> Jobs {get;}
+		List<Job> PendingJobs {get;}
 	}
 }
 
