@@ -17,26 +17,18 @@
 // 
 using System;
 using System.Collections.Generic;
-using LongoMatch.Store;
-using LongoMatch.Store.Templates;
+using LongoMatch.Core.Store;
+using LongoMatch.Core.Store.Templates;
 
-namespace LongoMatch.Interfaces
+namespace LongoMatch.Core.Interfaces
 {
 	public interface ITemplatesService
 	{
-		ITemplateProvider<T, U> GetTemplateProvider<T, U>() where T: ITemplate<U>;
-		
-		ISubcategoriesTemplatesProvider SubCategoriesTemplateProvider {get;}
+		ITemplateProvider<T> GetTemplateProvider<T>() where T: ITemplate;
 		
 		ITeamTemplatesProvider TeamTemplateProvider {get;}
 		
 		ICategoriesTemplatesProvider CategoriesTemplateProvider {get;}
-		
-		List<PlayerSubCategory> PlayerSubcategories {get;}
-		
-		List<TeamSubCategory> TeamSubcategories {get;}
-		
-		List<CoordinatesSubCategory> CoordinatesSubcategories {get;}
 	}
 }
 
