@@ -20,19 +20,17 @@
 
 using System;
 
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Store;
 
-namespace LongoMatch.Interfaces.Multimedia
+namespace LongoMatch.Core.Interfaces.Multimedia
 {
 
 
 	public interface IFramesCapturer
 	{
-		bool Open(string mrl);
-		bool SeekTime(long time, bool accurate);
-		void Pause();
+		bool Open (string uri);
 		void Dispose();
-		Image GetCurrentFrame(int outwidth, int outheight);
-		Image GetCurrentFrame();
+		Image GetFrame (Time pos, bool accurate, int outwidth=-1, int outheight=-1);
 	}
 }
