@@ -18,13 +18,17 @@
 using System;
 using System.Collections.Generic;
 
-using LongoMatch.Common;
-using LongoMatch.Store;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Store;
 
-namespace LongoMatch.Interfaces.Multimedia
+namespace LongoMatch.Core.Interfaces.Multimedia
 {
 	public interface IMultimediaToolkit
 	{
+		void Register (int priority, Type interfac, Type elementType);
+
+		IPlayer GetPlayer();
+
 		IVideoEditor GetVideoEditor();
 		
 		IVideoConverter GetVideoConverter (string filename);
@@ -33,9 +37,15 @@ namespace LongoMatch.Interfaces.Multimedia
 		
 		IRemuxer GetRemuxer(MediaFile inputFile, string outputFile, VideoMuxerType muxer);
 		
-		MediaFile DiscoverFile(string path);
+		ICapturer GetCapturer();
+		
+		MediaFile DiscoverFile(string path, bool takeScreenshot=true);
 		
 		List<Device> VideoDevices {get;}
+		
+		bool FileNeedsRemux (MediaFile file);
+		
+		string RemuxFile (MediaFile file, object parent);
 	}
 }
 
