@@ -21,10 +21,10 @@
 using System;
 using Gdk;
 
-using LongoMatch.Common;
-using LongoMatch.Handlers;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Handlers;
 
-namespace LongoMatch.Interfaces.Multimedia
+namespace LongoMatch.Core.Interfaces.Multimedia
 {
 
 
@@ -37,7 +37,7 @@ namespace LongoMatch.Interfaces.Multimedia
 
 		void Cancel();
 		
-		void AddFile(string filename, long duration);
+		void AddFile(string filename, long duration, uint width, uint height, double par);
 		
 		EncodingSettings EncodingSettings {set;}
 		
