@@ -19,14 +19,15 @@ using System;
 using System.Collections.Generic;
 
 
-namespace LongoMatch.Stats
+namespace LongoMatch.Core.Stats
 {
 	public class PercentualStat: Stat
 	{
 		int parentTotal;
 		
 		public PercentualStat (string name, int totalCount, int localTeamCount,
-			int visitorTeamCount, int parentTotal): base (name, totalCount, localTeamCount, visitorTeamCount)
+		                       int visitorTeamCount, int parentTotal): base (name, totalCount, localTeamCount, visitorTeamCount)
+
 		{
 			this.parentTotal = parentTotal;
 		}
