@@ -17,10 +17,14 @@
 // 
 using System;
 
-namespace LongoMatch.Stats
+namespace LongoMatch.Core.Stats
 {
 	public class Stat
 	{
+		public Stat ()
+		{
+		}
+
 		public Stat (string name, int totalCount, int localTeamCount, int visitorTeamCount)
 		{
 			Name = name;
@@ -28,7 +32,7 @@ namespace LongoMatch.Stats
 			LocalTeamCount = localTeamCount;
 			VisitorTeamCount = visitorTeamCount;
 		}
-		
+	
 		public string Name {
 			get;
 			set;
