@@ -21,9 +21,9 @@
 using System;
 using System.IO;
 
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
 
-namespace LongoMatch.Store
+namespace LongoMatch.Core.Store
 {
 
 	/// <summary>
@@ -33,35 +33,15 @@ namespace LongoMatch.Store
 	[Serializable]
 	public class PixbufTimeNode : TimeNode
 	{
-		private byte[] thumbnailBuf;
-		
-		#region Contructors
 		public PixbufTimeNode() {
 		}
-		#endregion
 
-		#region Properties
 		/// <summary>
 		/// Segment thumbnail
 		/// </summary>
 		public Image Miniature {
-			get {
-				if(thumbnailBuf != null)
-					return Image.Deserialize(thumbnailBuf);
-				else return null;
-			} set {
-				if (value == null)
-					thumbnailBuf = null;
-				else {
-					if (value.Height > Constants.THUMBNAIL_MAX_HEIGHT ||
-					    value.Width > Constants.THUMBNAIL_MAX_WIDTH) {
-						value.Scale(Constants.THUMBNAIL_MAX_WIDTH, Constants.THUMBNAIL_MAX_HEIGHT);
-					}
-					thumbnailBuf = value.Serialize();
-				}
-			}
+			get;
+			set;
 		}
-		
-		#endregion
 	}
 }
