@@ -17,7 +17,7 @@
 //
 using System;
 using Gtk;
-using LongoMatch.Common;
+using LongoMatch.Core.Common;
 using Misc = LongoMatch.Gui.Helpers.Misc;
 
 namespace LongoMatch.Gui.Component
@@ -31,17 +31,21 @@ namespace LongoMatch.Gui.Component
 		{
 			this.Build ();
 			
-			if (Config.FPS_N == 30000) {
+			if (Config.FPS_N == 30) {
 				fpscombobox.Active = 1;
+			} else if (Config.FPS_N == 50) {
+				fpscombobox.Active = 2;
+			} else if (Config.FPS_N == 60) {
+				fpscombobox.Active = 3;
 			} else {
 				fpscombobox.Active = 0;
 			}
 			fpscombobox.Changed += HandleFPSChanged;
-			Misc.FillImageFormat (renderimagecombo, Config.RenderVideoStandard);
+			Misc.FillImageFormat (renderimagecombo, VideoStandards.Rendering, Config.RenderVideoStandard);
 			Misc.FillEncodingFormat (renderenccombo, Config.RenderEncodingProfile);
 			Misc.FillQuality (renderqualcombo, Config.RenderEncodingQuality);
 			
-			Misc.FillImageFormat (captureimagecombo, Config.CaptureVideoStandard);
+			Misc.FillImageFormat (captureimagecombo, VideoStandards.Capture, Config.CaptureVideoStandard);
 			Misc.FillEncodingFormat (captureenccombo, Config.CaptureEncodingProfile);
 			Misc.FillQuality (capturequalcombo, Config.CaptureEncodingQuality);
 			
@@ -52,35 +56,53 @@ namespace LongoMatch.Gui.Component
 			captureenccombo.Changed += HandleEncodingChanged;  
 			
 			renderqualcombo.Changed += HandleQualityChanged;
-			captureimagecombo.Changed += HandleImageChanged;
+			capturequalcombo.Changed += HandleQualityChanged;
 			
-			enableSound  = new CheckButton();
+			enableSound = new CheckButton ();
 			rendertable.Attach (enableSound, 1, 2, 3, 4,
-			               AttachOptions.Fill,
-			               AttachOptions.Fill, 0, 0);
+			                    AttachOptions.Fill,
+			                    AttachOptions.Fill, 0, 0);
 			enableSound.CanFocus = false;
-			enableSound.Show();
+			enableSound.Show ();
 			enableSound.Active = Config.EnableAudio;
-			enableSound.Toggled += (sender, e) => {Config.EnableAudio = enableSound.Active;};
+			enableSound.Toggled += (sender, e) => {
+				Config.EnableAudio = enableSound.Active;};
 
-			overlayTitle  = new CheckButton();
+			overlayTitle = new CheckButton ();
 			rendertable.Attach (overlayTitle, 1, 2, 4, 5,
-			               AttachOptions.Fill,
-			               AttachOptions.Fill, 0, 0);
+			                    AttachOptions.Fill,
+			                    AttachOptions.Fill, 0, 0);
 			overlayTitle.CanFocus = false;
-			overlayTitle.Show();
+			overlayTitle.Show ();
 			overlayTitle.Active = Config.OverlayTitle;
-			overlayTitle.Toggled += (sender, e) => {Config.OverlayTitle = overlayTitle.Active;};
+			overlayTitle.Toggled += (sender, e) => {
+				Config.OverlayTitle = overlayTitle.Active;};
+			
+			SizeGroup sgroup = new SizeGroup (SizeGroupMode.Horizontal);
+			foreach (Widget w in capturetable) {
+				if (w is Label) {
+					sgroup.AddWidget (w);
+				}
+			}
+			foreach (Widget w in rendertable) {
+				if (w is Label) {
+					sgroup.AddWidget (w);
+				}
+			}
+			sgroup.AddWidget (fameratelabel);
 		}
 
 		void HandleFPSChanged (object sender, EventArgs e)
 		{
-			if (fpscombobox.ActiveText == "25 fps") {
+			Config.FPS_D = 1;
+			if (fpscombobox.Active == 0) {
 				Config.FPS_N = 25;
-				Config.FPS_D = 1;
-			} else {
+			} else if (fpscombobox.Active == 1) {
 				Config.FPS_N = 30;
-				Config.FPS_D = 1;
+			} else if (fpscombobox.Active == 2) {
+				Config.FPS_N = 50;
+			} else if (fpscombobox.Active == 3) {
+				Config.FPS_N = 60;
 			}
 		}
 
