@@ -19,8 +19,8 @@ using System;
 using System.Collections.Generic;
 using Gtk;
 
-using LongoMatch.Common;
-using LongoMatch.Interfaces;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Interfaces;
 
 
 namespace LongoMatch.Gui.Dialog
@@ -29,10 +29,10 @@ namespace LongoMatch.Gui.Dialog
 	{
 		IRenderingJobsManager manager;
 		
-		public RenderingJobsDialog (IRenderingJobsManager manager)
+		public RenderingJobsDialog ()
 		{
 			this.Build ();
-			this.manager = manager;
+			this.manager = Config.RenderingJobsManger;
 			UpdateModel();
 			cancelbutton.Clicked += OnCancelbuttonClicked;
 			clearbutton.Clicked += OnClearbuttonClicked;
