@@ -19,8 +19,8 @@
 //
 
 using System;
-using LongoMatch.Store;
-using LongoMatch.Handlers;
+using LongoMatch.Core.Store;
+using LongoMatch.Core.Handlers;
 
 namespace LongoMatch.Gui.Dialog
 {
