@@ -18,8 +18,9 @@
 
 using Gdk;
 using Gtk;
-using LongoMatch.Common;
-using LongoMatch.Store;
+using LongoMatch.Core.Common;
+using LongoMatch.Core.Store;
+using Misc = LongoMatch.Gui.Helpers.Misc;
 
 namespace LongoMatch.Gui.Component
 {
@@ -30,14 +31,10 @@ namespace LongoMatch.Gui.Component
 	public partial class PlayersTreeView : ListTreeViewBase
 	{
 
-		private Menu playersMenu;
-
+		TreePath pathClicked;
 
 		public PlayersTreeView() {
 			this.Team = Team.LOCAL;
-			tag.Visible = false;
-			delete.Visible = false;
-			SetPlayersMenu();
 		}
 
 		public Team Team {
@@ -45,31 +42,6 @@ namespace LongoMatch.Gui.Component
 			get;
 		}
 
-		private void SetPlayersMenu() {
-			Action edit;
-			UIManager manager;
-			ActionGroup g;
-
-			manager= new UIManager();
-			g = new ActionGroup("PlayersMenuGroup");
-
-			edit = new Action("EditAction", Mono.Unix.Catalog.GetString("Edit name"), null, "gtk-edit");
-
-			g.Add(edit, null);
-
-			manager.InsertActionGroup(g,0);
-
-			manager.AddUiFromString("<ui>"+
-			                        "  <popup action='PlayersMenu'>"+
-			                        "    <menuitem action='EditAction'/>"+
-			                        "  </popup>"+
-			                        "</ui>");
-
-			playersMenu = manager.GetWidget("/PlayersMenu") as Menu;
-
-			edit.Activated += OnEdit;
-		}
-
 		protected override int SortFunction(TreeModel model, TreeIter a, TreeIter b) {
 			object oa;
 			object ob;
@@ -80,10 +52,18 @@ namespace LongoMatch.Gui.Component
 			oa = model.GetValue(a, 0);
 			ob = model.GetValue(b, 0);
 
+			if (oa == null && ob == null) {
+				return 0;
+			} else if (oa == null) {
+				return -1;
+			} else if (ob == null) {
+				return 1;
+			}
+
 			if(oa is Player)
 				return (oa as Player).Number.CompareTo((ob as Player).Number);
 			else
-				return (oa as TimeNode).Name.CompareTo((ob as TimeNode).Name);
+				return (oa as TimeNode).Start.CompareTo((ob as TimeNode).Start);
 		}
 
 		override protected bool OnKeyPressEvent(Gdk.EventKey evnt)
@@ -91,43 +71,44 @@ namespace LongoMatch.Gui.Component
 			return false;
 		}
 
-		override protected void OnNameCellEdited(object o, Gtk.EditedArgs args)
+		protected override bool OnButtonReleaseEvent (Gdk.EventButton evnt)
 		{
-			base.OnNameCellEdited(o, args);
-			Model.SetSortFunc(0, SortFunction);
+			if (pathClicked != null) {
+				if (GetRowExpanded (pathClicked)) {
+					CollapseRow (pathClicked);
+				} else {
+					ExpandRow (pathClicked, true);
+				}
+				pathClicked = null;
+			}
+			return base.OnButtonReleaseEvent (evnt);
 		}
 
-		override protected bool OnButtonPressEvent(EventButton evnt)
+		override protected bool OnButtonPressEvent (Gdk.EventButton evnt)
 		{
-			TreePath[] paths = Selection.GetSelectedRows();
+			TreePath[] paths = Selection.GetSelectedRows ();
 
-			if((evnt.Type == EventType.ButtonPress) && (evnt.Button == 3))
-			{
+			if (Misc.RightButtonClicked (evnt)) {
 				// We don't want to unselect the play when several
 				// plays are selected and we clik the right button
 				// For multiedition
-				if(paths.Length <= 1) {
-					base.OnButtonPressEvent(evnt);
-					paths = Selection.GetSelectedRows();
+				if (paths.Length <= 1) {
+					base.OnButtonPressEvent (evnt);
+					paths = Selection.GetSelectedRows ();
 				}
 
-				if(paths.Length == 1) {
-					TimeNode selectedTimeNode = GetValueFromPath(paths[0]) as TimeNode;
-					if(selectedTimeNode is Play) {
-						deleteKeyFrame.Sensitive = (selectedTimeNode as Play).HasDrawings;
-						MultiSelectMenu(false);
-						menu.Popup();
-					} else {
-						playersMenu.Popup();
+				if (paths.Length == 1) {
+					TimeNode selectedTimeNode = GetValueFromPath (paths [0]) as TimeNode;
+					if (selectedTimeNode is TimelineEvent) {
+						ShowMenu ();
 					}
+				} else if (paths.Length > 1) {
+					ShowMenu ();
 				}
-				else if(paths.Length > 1) {
-					MultiSelectMenu(true);
-					menu.Popup();
-				}
-			}
-			else
+			} else {
+				GetPathAtPos ((int) evnt.X, (int) evnt.Y, out pathClicked);
 				base.OnButtonPressEvent(evnt);
+			}
 			return true;
 		}
 
