@@ -19,4 +19,7 @@ using System;
 using Mono.Addins;
 
 [assembly:Addin]
-[assembly:AddinDependency ("LongoMatch", "1.0")]
\ No newline at end of file
+[assembly:AddinAuthor ("LongoMatch Project")]
+[assembly:AddinName ("LongoMatch plugins")]
+[assembly:AddinDescription ("LongoMatch default import and dashboard plugins")]
+[assembly:AddinDependency ("LongoMatch", "1.1")]
\ No newline at end of file
