@@ -28,7 +28,7 @@
 #include <gst/app/gstappsink.h>
 #include <gst/app/gstappsrc.h>
 
-#include "video-utils.h"
+#include "lgm-utils.h"
 #include "gst-nle-source.h"
 
 GST_DEBUG_CATEGORY (_nlesrc_gst_debug_cat);
@@ -45,7 +45,7 @@ static GstStaticPadTemplate video_tpl = GST_STATIC_PAD_TEMPLATE ("video",
     GST_PAD_SRC,
     GST_PAD_SOMETIMES,
     GST_STATIC_CAPS ("video/x-raw-yuv, format=(fourcc)I420, "
-        "width=[1,2160], height=[1,2160], framerate={25/1, 30/1}"));
+        "width=[1,2160], height=[1,2160], framerate={25/1, 30/1, 50/1, 60/1}"));
 
 static GstStaticPadTemplate audio_tpl = GST_STATIC_PAD_TEMPLATE ("audio",
     GST_PAD_SRC,
@@ -287,8 +287,9 @@ gst_nle_source_push_buffer (GstNleSource * nlesrc, GstBuffer * buf,
 
   if (buf_ts < item->start) {
     GST_LOG_OBJECT (nlesrc, "Discard early %s buffer with ts: %"
-      GST_TIME_FORMAT" start: %" GST_TIME_FORMAT, is_audio ? "audio" : "video",
-      GST_TIME_ARGS (buf_ts), GST_TIME_ARGS (item->start));
+        GST_TIME_FORMAT " start: %" GST_TIME_FORMAT,
+        is_audio ? "audio" : "video", GST_TIME_ARGS (buf_ts),
+        GST_TIME_ARGS (item->start));
     gst_buffer_unref (buf);
     return GST_FLOW_OK;
   }
@@ -336,7 +337,7 @@ gst_nle_source_push_buffer (GstNleSource * nlesrc, GstBuffer * buf,
 }
 
 static GstBuffer *
-gst_nle_source_audio_silence_buf (GstNleSource *nlesrc, guint64 start,
+gst_nle_source_audio_silence_buf (GstNleSource * nlesrc, guint64 start,
     guint64 duration)
 {
   GstBuffer *buf;
@@ -375,17 +376,17 @@ gst_nle_source_no_more_pads (GstElement * element, GstNleSource * nlesrc)
     duration = item->duration / item->rate;
 
     /* Push the start buffer and last 2 ones and let audiorate fill the gap */
-    buf = gst_nle_source_audio_silence_buf (nlesrc, item->start, 20 * GST_MSECOND);
-    gst_nle_source_push_buffer (nlesrc, buf, TRUE);
-
-    buf = gst_nle_source_audio_silence_buf (nlesrc,
-        item->start + duration - 40 * GST_MSECOND,
+    buf =
+        gst_nle_source_audio_silence_buf (nlesrc, item->start,
         20 * GST_MSECOND);
     gst_nle_source_push_buffer (nlesrc, buf, TRUE);
 
     buf = gst_nle_source_audio_silence_buf (nlesrc,
-        item->start + duration - 20 * GST_MSECOND,
-        20 * GST_MSECOND);
+        item->start + duration - 40 * GST_MSECOND, 20 * GST_MSECOND);
+    gst_nle_source_push_buffer (nlesrc, buf, TRUE);
+
+    buf = gst_nle_source_audio_silence_buf (nlesrc,
+        item->start + duration - 20 * GST_MSECOND, 20 * GST_MSECOND);
     gst_nle_source_push_buffer (nlesrc, buf, TRUE);
   }
 }
@@ -411,6 +412,14 @@ gst_nle_source_on_video_buffer (GstAppSink * appsink, gpointer data)
 
   if (item->still_picture) {
     GstBuffer *end_buf;
+    GstCaps *bcaps, *ncaps;
+
+    bcaps = gst_buffer_get_caps (buf);
+    ncaps = gst_caps_make_writable (bcaps);
+    gst_caps_set_simple (ncaps, "pixel-aspect-ratio", GST_TYPE_FRACTION,
+        1, 1, NULL);
+    gst_buffer_set_caps (buf, ncaps);
+    gst_caps_unref (ncaps);
 
     end_buf = gst_buffer_copy (buf);
 
@@ -515,6 +524,9 @@ gst_nle_source_pad_added_cb (GstElement * element, GstPad * pad,
   GstElement *appsink = NULL;
   GstPad *sink_pad;
   GstAppSinkCallbacks appsink_cbs;
+  GstNleSrcItem *item;
+
+  item = (GstNleSrcItem *) g_list_nth_data (nlesrc->queue, nlesrc->index);
 
   caps = gst_pad_get_caps_reffed (pad);
   s = gst_caps_get_structure (caps, 0);
@@ -537,7 +549,7 @@ gst_nle_source_pad_added_cb (GstElement * element, GstPad * pad,
         (GCallback) gst_nle_source_video_pad_probe_cb, nlesrc);
     nlesrc->video_eos = FALSE;
   } else if (g_strrstr (mime, "audio") && nlesrc->with_audio
-      && !nlesrc->audio_linked) {
+      && !nlesrc->audio_linked && (item ? item->rate == 1.0 : TRUE)) {
     appsink = gst_element_factory_make ("appsink", NULL);
     memset (&appsink_cbs, 0, sizeof (appsink_cbs));
     appsink_cbs.eos = gst_nle_source_on_audio_eos;
@@ -610,6 +622,8 @@ gst_nle_source_next (GstNleSource * nlesrc)
   uridecodebin = gst_element_factory_make ("uridecodebin", NULL);
   gst_bin_add (GST_BIN (nlesrc->decoder), uridecodebin);
 
+  g_signal_connect (uridecodebin, "autoplug-select",
+      G_CALLBACK (lgm_filter_video_decoders), nlesrc);
   g_signal_connect (uridecodebin, "pad-added",
       G_CALLBACK (gst_nle_source_pad_added_cb), nlesrc);
   g_signal_connect (uridecodebin, "no-more-pads",
@@ -642,8 +656,7 @@ gst_nle_source_next (GstNleSource * nlesrc)
   GST_DEBUG_OBJECT (nlesrc, "Start ts:%" GST_TIME_FORMAT,
       GST_TIME_ARGS (nlesrc->start_ts));
   gst_element_set_state (nlesrc->decoder, GST_STATE_PLAYING);
-  ret = gst_element_get_state (nlesrc->decoder, &state,
-      NULL, 5 * GST_SECOND);
+  ret = gst_element_get_state (nlesrc->decoder, &state, NULL, 5 * GST_SECOND);
   if (ret == GST_STATE_CHANGE_FAILURE) {
     GST_WARNING_OBJECT (nlesrc, "Error changing state, selecting next item.");
     gst_nle_source_check_eos (nlesrc);
@@ -682,12 +695,28 @@ gst_nle_source_change_state (GstElement * element, GstStateChange transition)
     return res;
 
   switch (transition) {
+    case GST_STATE_CHANGE_PLAYING_TO_PAUSED:
+      if (nlesrc->decoder) {
+        gst_element_set_state (nlesrc->decoder, GST_STATE_PAUSED);
+      }
+      break;
     case GST_STATE_CHANGE_PAUSED_TO_READY:
+      if (nlesrc->decoder) {
+        gst_element_set_state (nlesrc->decoder, GST_STATE_READY);
+      }
+      if (nlesrc->queue != NULL) {
+        g_list_free_full (nlesrc->queue,
+            (GDestroyNotify) gst_nle_source_item_free);
+        nlesrc->queue = NULL;
+      }
+      break;
+    case GST_STATE_CHANGE_READY_TO_NULL:
       if (nlesrc->decoder) {
         gst_element_set_state (nlesrc->decoder, GST_STATE_NULL);
         gst_object_unref (nlesrc->decoder);
         nlesrc->decoder = NULL;
       }
+      break;
     default:
       break;
   }
