@@ -25,7 +25,7 @@
 #include <gst/gst.h>
 #include "gst-video-editor.h"
 #include "gst-nle-source.h"
-#include "video-utils.h"
+#include "lgm-utils.h"
 
 
 #define AUDIO_INT_CAPS "audio/x-raw-int, rate=44100, channels=2"
@@ -235,7 +235,7 @@ gve_create_video_encode_bin (GstVideoEditor * gve)
   gve->priv->queue = gst_element_factory_make ("queue2", "video-encode-queue");
   gve->priv->video_encoder =
       lgm_create_video_encoder (gve->priv->video_encoder_type,
-      gve->priv->video_quality, GVE_ERROR, &error);
+      gve->priv->video_quality, FALSE, GVE_ERROR, &error);
   if (error) {
     g_signal_emit (gve, gve_signals[SIGNAL_ERROR], 0, error->message);
     g_error_free (error);
@@ -389,7 +389,7 @@ gve_bus_message_cb (GstBus * bus, GstMessage * message, gpointer data)
     case GST_MESSAGE_ERROR:
       gve_error_msg (gve, message);
       if (gve->priv->main_pipeline)
-        gst_element_set_state (gve->priv->main_pipeline, GST_STATE_READY);
+        gst_element_set_state (gve->priv->main_pipeline, GST_STATE_NULL);
       break;
     case GST_MESSAGE_WARNING:
       GST_WARNING ("Warning message: %" GST_PTR_FORMAT, message);
@@ -426,10 +426,10 @@ gve_bus_message_cb (GstBus * bus, GstMessage * message, gpointer data)
       }
       if (old_state == GST_STATE_NULL && new_state == GST_STATE_READY)
         GST_DEBUG_BIN_TO_DOT_FILE (GST_BIN (gve->priv->main_pipeline),
-            GST_DEBUG_GRAPH_SHOW_ALL, "gst-camera-capturer-null-to-ready");
+            GST_DEBUG_GRAPH_SHOW_ALL, "longomatch-editor-null-to-ready");
       if (old_state == GST_STATE_READY && new_state == GST_STATE_PAUSED)
         GST_DEBUG_BIN_TO_DOT_FILE (GST_BIN (gve->priv->main_pipeline),
-            GST_DEBUG_GRAPH_SHOW_ALL, "gst-camera-capturer-ready-to-paused");
+            GST_DEBUG_GRAPH_SHOW_ALL, "longomatch-editor-ready-to-paused");
       break;
     }
     case GST_MESSAGE_EOS:
@@ -464,6 +464,8 @@ gve_error_msg (GstVideoEditor * gve, GstMessage * msg)
 
   g_message ("Error: %s\n%s\n", GST_STR_NULL (err->message),
       GST_STR_NULL (dbg));
+  GST_DEBUG_BIN_TO_DOT_FILE(GST_BIN(gve->priv->main_pipeline),
+      GST_DEBUG_GRAPH_SHOW_ALL, "longomatch-editor-error");
   g_signal_emit (gve, gve_signals[SIGNAL_ERROR], 0, err->message);
   g_error_free (err);
   g_free (dbg);
@@ -610,13 +612,6 @@ gst_video_editor_start (GstVideoEditor * gve)
   g_signal_emit (gve, gve_signals[SIGNAL_PERCENT_COMPLETED], 0, (gfloat) 0);
 }
 
-static void
-_set_state_threaded (GstVideoEditor *gve)
-{
-  gst_element_set_state (gve->priv->main_pipeline, GST_STATE_NULL);
-  g_signal_emit (gve, gve_signals[SIGNAL_PERCENT_COMPLETED], 0, (gfloat) - 1);
-}
-
 void
 gst_video_editor_cancel (GstVideoEditor * gve)
 {
@@ -627,7 +622,7 @@ gst_video_editor_cancel (GstVideoEditor * gve)
     g_source_remove (gve->priv->update_id);
     gve->priv->update_id = 0;
   }
-  g_thread_new ("cancel", (GThreadFunc) _set_state_threaded, gve);
+  gst_element_set_state (gve->priv->main_pipeline, GST_STATE_NULL);
 }
 
 void
