@@ -29,10 +29,8 @@
 #endif
 
 #include <glib-object.h>
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
 
-#include "common.h"
+#include "lgm-utils.h"
 
 G_BEGIN_DECLS
 #define GST_TYPE_VIDEO_ENCODER             (gst_video_encoder_get_type ())
@@ -85,7 +83,10 @@ EXPORT void gst_video_encoder_set_encoding_format              (GstVideoEncoder
 
 EXPORT void gst_video_encoder_add_file                         (GstVideoEncoder * gve,
                                                                 const gchar * file,
-                                                                guint64 duration);
+                                                                guint64 duration,
+                                                                guint width,
+                                                                guint height,
+                                                                gdouble par);
 
 EXPORT gboolean gst_video_encoder_dump_graph                   (GstVideoEncoder *gve);
 
